@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-06-02 11:08:39
-@LastEditTime: 2023-02-15 17:03:10
+@LastEditTime: 2023-02-21 11:47:23
 @LastEditors: HuangJianYi
 :description: 订单相关
 """
@@ -42,7 +42,7 @@ class PayOrderListHandler(SevenBaseHandler):
 
         condition = "act_id=%s"
         params = [act_id]
-        field = "id,order_no,user_nick,goods_name,sku_name,buy_num,pay_price,pay_date,main_order_no"
+        field = "id,order_no,user_nick,goods_name,sku_name,buy_num,pay_price,pay_date,main_order_no,open_id"
         if user_open_id:
             condition += " AND open_id=%s"
             params.append(user_open_id)
